@@ -1,7 +1,8 @@
 #' spec_result_create_table_with_data_type
+#' @family result specifications
 #' @usage NULL
 #' @format NULL
-#' @keywords internal
+#' @keywords NULL
 spec_result_create_table_with_data_type <- list(
   #' @section Specification:
   #' All data types returned by `dbDataType()` are usable in an SQL statement
@@ -9,11 +10,10 @@ spec_result_create_table_with_data_type <- list(
   data_type_create_table = function(ctx, con) {
     check_connection_data_type <- function(value) {
       table_name <- random_table_name()
-      with_remove_test_table(name = table_name, {
-        #' `"CREATE TABLE test (a ...)"`.
-        query <- paste0("CREATE TABLE ", table_name, " (a ", dbDataType(con, value), ")")
-        eval(bquote(dbExecute(con, .(query))))
-      })
+      local_remove_test_table(con, table_name)
+      #' `"CREATE TABLE test (a ...)"`.
+      query <- paste0("CREATE TABLE ", table_name, " (a ", dbDataType(con, value), ")")
+      eval(bquote(dbExecute(con, .(query))))
     }
 
     expect_conn_has_data_type <- function(value) {
